@@ -36,7 +36,7 @@ class SlurmCommands(object):
 
     @staticmethod
     def get_job_id_from_output(queue_submit_output):
-        return int(queue_submit_output.splitlines()[-1].rstrip().lstrip())
+        return int(queue_submit_output.splitlines()[-1].rstrip().lstrip().split()[-1])
 
     @staticmethod
     def convert_queue_status(queue_status_output):
